/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/03
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy;

/**
 * Jiemamyのバージョンを表すインターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface Version {
	
	/** 仕様のメジャーバージョン番号 */
	int MAJOR = 0;
	
	/** 仕様のマイナーバージョン番号 */
	int MINOR = 2;
	
	/** 仕様がスナップショット版であるかどうか */
	boolean SNAPSHOT = false;
	
	/** 仕様バージョンの文字列表記 */
	String SPEC = MAJOR + "." + MINOR + (SNAPSHOT ? "-SNAPSHOT" : "");
	

	/**
	 * 仕様及び実装のメジャーバージョン番号を取得する。
	 * 
	 * @return 仕様及び実装のメジャーバージョン番号
	 * @since 0.2
	 */
	int getMajor();
	
	/**
	 * 仕様及び実装のマイナーバージョン番号を取得する。
	 * 
	 * @return 仕様及び実装のマイナーバージョン番号
	 * @since 0.2
	 */
	int getMinor();
	
	/**
	 * 実装のリリース番号を取得する。
	 * 
	 * @return 実装のリリース番号
	 * @since 0.2
	 */
	int getRelease();
	
	/**
	 * スナップショット版であるかどうかを取得する。
	 * 
	 * <p>仕様または実装のいずれかがスナップショット版であれば、{@code true}を返す。両者とも正式版の時のみ、{@code false}を返す。</p>
	 * 
	 * @return スナップショット版であれば{@code true}
	 * @since 0.2
	 */
	boolean isSnapshot();
}
