/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/31
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.dialect.internal;

import org.jiemamy.dialect.ConnectionAdvisor;
import org.jiemamy.dialect.DataTypeResolver;
import org.jiemamy.dialect.MoldManager;
import org.jiemamy.model.RootModel;
import org.jiemamy.model.datatype.DataType;

/**
 * SQL方言の各ストラテジを提供するイニシャライザインターフェイス。
 * 
 * <p>{@link AbstractDialect}を初期化するための情報を取得することができる。</p>
 * 
 * @author daisuke
 */
public interface DialectInitializer {
	
	/**
	 * DBメタデータの読み出し前後に実行するロジッククラスを取得する。
	 * 
	 * @return DBメタデータの読み出し前後に実行するロジッククラス
	 */
	ConnectionAdvisor getConnectionAdvisor();
	
	/**
	 * データ型（{@link DataType}）を中心とした各種解決を行うロジッククラスを取得する。
	 * 
	 * @return データ型（{@link DataType}）を中心とした各種解決を行うロジッククラス
	 */
	DataTypeResolver getDataTypeResolver();
	
	/**
	 * エンティティメタ情報から{@link RootModel}にインポートを行うビジターを取得する。
	 * 
	 * @return エンティティメタ情報から{@link RootModel}にインポートを行うビジター
	 */
	EntityImportVisitor getEntityImportVisitor();
	
	/**
	 * 外部キーメタ情報から{@link RootModel}にインポートを行うビジターを取得する。
	 * 
	 * @return 外部キーメタ情報から{@link RootModel}にインポートを行うビジター
	 */
	ForeignKeyImportVisitor getForeignKeyImportVisitor();
	
	/**
	 * データ型鋳型の管理クラスを取得する。
	 * 
	 * @return データ型鋳型の管理クラス
	 */
	MoldManager getMoldManager();
	
	/**
	 * {@link RootModel}からSQLのリストを生成するエミッタを取得する。
	 * 
	 * @return {@link RootModel}からSQLのリストを生成するエミッタ
	 */
	SqlEmitter getSqlEmitter();
}
