/*
 * Copyright 2007-2009 MIYAMOTO Daisuke, jiemamy.org and the Others.
 * Created on 2009/01/01
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.experimental.builder;

import org.jiemamy.model.JiemamyElement;

/**
 * {@link JiemamyElement}を簡単に構築するためのビルダインターフェイス。
 * 
 * @param <T> 構築するモデルの型
 * @author daisuke
 */
public interface JiemamyBuilder<T extends JiemamyElement> {
	
	/**
	 * モデルを構築する。
	 * 
	 * @return model 構築されたモデル
	 * @throws IllegalStateException 過去に一度既にビルドを行っている場合
	 * @throws IllegalStateException 必要な操作が行われていない場合
	 * @since 0.2
	 */
	T build();
	
	/**
	 * モデルを構築する。
	 * 
	 * @param force 必要な操作が行われていなくても、強制的にビルドを行う場合は{@code true}、そうでない場合は{@code false}
	 * @return model 構築されたモデル
	 * @throws IllegalStateException 過去に一度既にビルドを行っている場合
	 * @throws IllegalStateException forceが{@code false}の時、必要な操作が行われていない場合
	 * @since 0.2
	 */
	T build(boolean force);
	
}
