/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/04
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.builder;

import org.apache.commons.lang.Validate;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.dialect.BuiltinDataTypeMold;
import org.jiemamy.dialect.Dialect;
import org.jiemamy.dialect.generic.GenericDialect;
import org.jiemamy.experimental.builder.DataTypeBuilder;
import org.jiemamy.model.RootModel;
import org.jiemamy.model.datatype.BuiltinDataType;
import org.jiemamy.model.datatype.DataTypeCategory;
import org.jiemamy.model.datatype.adapter.PrecisionedDataTypeAdapter;
import org.jiemamy.model.datatype.adapter.SizedDataTypeAdapter;

/**
 * {@link BuiltinDataType}を構築するためのビルダー実装クラス。
 * 
 * @author daisuke
 */
public class DataTypeBuilderImpl implements DataTypeBuilder {
	
	private static Logger logger = LoggerFactory.getLogger(DataTypeBuilderImpl.class);
	
	private BuiltinDataType model;
	
	private boolean finished;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory モデル生成のためのファクトリ
	 * @param category 生成するデータ型のカテゴリ
	 */
	public DataTypeBuilderImpl(JiemamyFactory factory, DataTypeCategory category) {
		Validate.notNull(factory);
		RootModel rootModel = factory.getRootModel();
		Dialect dialect;
		try {
			dialect = rootModel.findDialect();
		} catch (ClassNotFoundException e) {
			logger.warn("Dialectのロスト", e);
			dialect = new GenericDialect();
		}
		BuiltinDataTypeMold mold = dialect.findDataTypeMold(category);
		model = factory.newDataType(mold);
	}
	
	public BuiltinDataType build() {
		if (finished) {
			throw new IllegalStateException();
		}
		finished = true;
		return model;
	}
	
	public DataTypeBuilder setPrecision(int precision) {
		model.getAdapter(PrecisionedDataTypeAdapter.class).setPrecision(precision);
		return this;
	}
	
	public DataTypeBuilder setScale(int scale) {
		model.getAdapter(PrecisionedDataTypeAdapter.class).setScale(scale);
		return this;
	}
	
	public DataTypeBuilder setSize(int size) {
		model.getAdapter(SizedDataTypeAdapter.class).setSize(size);
		return this;
	}
	
}
