/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/12/24
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.builder;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.experimental.builder.TableBuilder;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.constraint.PrimaryKey;
import org.jiemamy.model.entity.TableModel;

/**
 * {@link TableModel}を構築するためのビルダー実装クラス。
 * 
 * @author daisuke
 */
public class TableBuilderImpl extends AbstractJiemamyBuilder<TableModel> implements TableBuilder {
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory モデル生成のためのファクトリ
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public TableBuilderImpl(JiemamyFactory factory) {
		super(factory, TableModel.class);
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param factory モデル生成のためのファクトリ
	 * @param name テーブル名
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public TableBuilderImpl(JiemamyFactory factory, String name) {
		super(factory, TableModel.class);
		Validate.notNull(name);
		model.setName(name);
	}
	
	public TableBuilder addColumn(ColumnModel columnModel) {
		model.getAttributes().add(columnModel);
		return this;
	}
	
	/**
	 * 主キーをカラムのインデックスで指定する。
	 * 
	 * @param index カラムのインデックス
	 * @param otherIndexes 2つ目以降のカラムのインデックス
	 * @return this
	 * @throws IndexOutOfBoundsException 指定したインデックスのカラムが存在しない場合。
	 */
	public TableBuilder primaryKey(int index, int... otherIndexes) {
		PrimaryKey primaryKey = factory.newModel(PrimaryKey.class);
		ColumnModel pkColumn = model.findColumns().get(index);
		primaryKey.getKeyColumns().add(factory.newReference(pkColumn));
		
		for (int otherIndex : otherIndexes) {
			pkColumn = model.findAttributes(ColumnModel.class).get(otherIndex);
			if (primaryKey.getKeyColumns().contains(pkColumn) == false) {
				primaryKey.getKeyColumns().add(factory.newReference(pkColumn));
			}
		}
		
		model.getAttributes().add(primaryKey);
		return this;
	}
	
	public TableBuilder setName(String name) {
		model.setName(name);
		return this;
	}
	
	@Override
	boolean isComplete() {
		return model.getName() != null;
	}
}
