/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/18
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import java.util.Collection;

import org.apache.commons.lang.Validate;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.attribute.AttributeModel;
import org.jiemamy.model.entity.TableModel;

/**
 * {@link AttributeModel}を{@link TableModel}に追加するEDITコマンド。
 * 
 * @author daisuke
 */
public class AddAttributeCommand extends AbstractAddToCollectionCommand<TableModel, AttributeModel> {
	
	/** 追加されるテーブル */
	private final TableModel tableModel;
	
	/** 追加する属性 */
	private final AttributeModel attributeModel;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param tableModel 追加されるテーブル
	 * @param attributeModel 追加するカラム
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddAttributeCommand(EventBroker eventBroker, TableModel tableModel, AttributeModel attributeModel) {
		super(eventBroker, tableModel, attributeModel);
		Validate.notNull(tableModel);
		Validate.notNull(attributeModel);
		
		this.tableModel = tableModel;
		this.attributeModel = attributeModel;
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param tableModel 追加されるテーブル
	 * @param index 追加位置をあらわすインデックス値
	 * @param attributeModel 追加するカラム
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddAttributeCommand(EventBroker eventBroker, TableModel tableModel, int index, AttributeModel attributeModel) {
		super(eventBroker, tableModel, attributeModel, index);
		Validate.notNull(tableModel);
		Validate.notNull(attributeModel);
		
		this.tableModel = tableModel;
		this.attributeModel = attributeModel;
	}
	
	public Command getNegateCommand() {
		return new RemoveAttributeCommand(getEventBroker(), tableModel, attributeModel);
	}
	
	@Override
	public Collection<? super AttributeModel> getTargetCollection() {
		return tableModel.getAttributes();
	}
	
}
