/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/02
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import java.util.Collection;
import java.util.List;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.ConnectionProfile;
import org.jiemamy.model.geometory.JmPoint;

/**
 * コネクションにベンドポイントを追加するEDITコマンド。
 * 
 * @author daisuke
 */
public class AddBendpointCommand extends AbstractAddToCollectionCommand<ConnectionProfile, JmPoint> {
	
	/** ベンドポイントのリスト */
	private final List<JmPoint> bendpoints;
	
	/** ダイアグラムエディタのインデックス（エディタ内のタブインデックス） */
	private final int diagramIndex;
	
	/** ベンドポイントが追加されるコネクション */
	private final ConnectionProfile connectionProfile;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param diagramIndex ダイアグラムエディタのインデックス（エディタ内のタブインデックス）
	 * @param connectionProfile ベンドポイントが追加されるコネクションのビジュアル情報
	 * @param bendpointIndex source側からtarget側に向かって数えたベンドポイントのインデックス
	 * @param point 座標
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddBendpointCommand(EventBroker eventBroker, int diagramIndex, ConnectionProfile connectionProfile,
			int bendpointIndex, JmPoint point) {
		super(eventBroker, connectionProfile, point, bendpointIndex);
		this.diagramIndex = diagramIndex;
		this.connectionProfile = connectionProfile;
		bendpoints = connectionProfile.getBendpoints();
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param diagramIndex ダイアグラムエディタのインデックス（エディタ内のタブインデックス）
	 * @param connectionProfile ベンドポイントが追加されるコネクションのビジュアル情報
	 * @param point 座標
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddBendpointCommand(EventBroker eventBroker, int diagramIndex, ConnectionProfile connectionProfile,
			JmPoint point) {
		super(eventBroker, connectionProfile, point);
		this.diagramIndex = diagramIndex;
		this.connectionProfile = connectionProfile;
		bendpoints = connectionProfile.getBendpoints();
	}
	
	public Command getNegateCommand() {
		if (getIndex() != -1) {
			return new RemoveBendpointCommand(getEventBroker(), diagramIndex, connectionProfile, getIndex());
		} else {
			return new RemoveBendpointCommand(getEventBroker(), diagramIndex, connectionProfile, getElement());
		}
	}
	
	@Override
	public Collection<? super JmPoint> getTargetCollection() {
		return bendpoints;
	}
}
