/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/21
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import java.util.List;

import org.apache.commons.lang.Validate;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.internal.model.attribute.ColumnRefImpl;
import org.jiemamy.model.JiemamyElement;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.ColumnRef;

/**
 * {@link ColumnRef}のリストに{@link ColumnModel}を追加するEDITコマンド。
 * 
 * @author shin1ogawa
 */
public class AddColumnToColumnRefListCommand extends AbstractCommand {
	
	/** 操作対象の{@link JiemamyElement} */
	private final JiemamyElement target;
	
	/** 追加対象のリスト */
	private final List<ColumnRef> columnRefList;
	
	/** 追加されるカラム */
	private final ColumnModel columnModel;
	
	/** 追加位置インデックス */
	private final int index;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param target 操作対象の{@link JiemamyElement}
	 * @param columnRefList 追加対象のリスト
	 * @param columnModel 追加されるカラム
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddColumnToColumnRefListCommand(EventBroker eventBroker, JiemamyElement target,
			List<ColumnRef> columnRefList, ColumnModel columnModel) {
		this(eventBroker, target, columnRefList, columnModel, columnRefList.size());
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param target 操作対象の{@link JiemamyElement}
	 * @param columnRefList 追加対象のリスト
	 * @param columnModel 追加されるカラム
	 * @param index 追加位置インデックス
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddColumnToColumnRefListCommand(EventBroker eventBroker, JiemamyElement target,
			List<ColumnRef> columnRefList, ColumnModel columnModel, int index) {
		super(eventBroker);
		Validate.notNull(target);
		Validate.notNull(columnRefList);
		Validate.notNull(columnModel);
		
		this.target = target;
		this.columnRefList = columnRefList;
		this.columnModel = columnModel;
		this.index = index;
	}
	
	public Command getNegateCommand() {
		return new RemoveColumnFromColumnRefListCommand(getEventBroker(), target, columnRefList, columnModel, index);
	}
	
	public JiemamyElement getTarget() {
		return target;
	}
	
	@Override
	protected void execute0() {
		columnRefList.add(index, new ColumnRefImpl(columnModel));
	}
}
