/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/02/22
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import org.apache.commons.lang.Validate;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.ConnectionProfile;
import org.jiemamy.model.DiagramPresentationModel;
import org.jiemamy.model.DiagramPresentations;
import org.jiemamy.model.JiemamyElement;
import org.jiemamy.model.RootModel;
import org.jiemamy.model.connection.ConnectionAdapter;

/**
 * {@link RootModel}に登録された{@link DiagramPresentations}アダプタに{@link ConnectionAdapter}を追加するEDITコマンド。
 * 
 * @see RemoveConnectionViewCommand
 * @author shin1ogawa
 */
public class AddConnectionViewCommand extends AbstractCommand {
	
	/** {@link DiagramPresentations}がアダプトされた{@link RootModel} */
	private final RootModel rootModel;
	
	/** コネクション */
	private final ConnectionAdapter connectionAdapter;
	
	/** コネクションのビジュアル情報 */
	private final ConnectionProfile connectionProfile;
	
	/** ダイアグラムエディタのインデックス（エディタ内のタブインデックス） */
	private final int diagramIndex;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param rootModel {@link DiagramPresentations}がアダプトされた{@link RootModel}
	 * @param diagramIndex ダイアグラムエディタのインデックス（エディタ内のタブインデックス）
	 * @param connectionAdapter コネクション
	 * @param connectionProfile コネクションのビジュアル情報
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddConnectionViewCommand(EventBroker eventBroker, RootModel rootModel, int diagramIndex,
			ConnectionAdapter connectionAdapter, ConnectionProfile connectionProfile) {
		super(eventBroker);
		Validate.notNull(rootModel);
		Validate.notNull(connectionAdapter);
		Validate.notNull(connectionProfile);
		this.rootModel = rootModel;
		this.diagramIndex = diagramIndex;
		this.connectionAdapter = connectionAdapter;
		this.connectionProfile = connectionProfile;
	}
	
	public Command getNegateCommand() {
		return new RemoveConnectionViewCommand(getEventBroker(), rootModel, diagramIndex, connectionAdapter);
	}
	
	public JiemamyElement getTarget() {
		return rootModel;
	}
	
	@Override
	protected void execute0() {
		DiagramPresentations diagramPresentations = rootModel.getAdapter(DiagramPresentations.class);
		DiagramPresentationModel diagramPresentationModel = diagramPresentations.get(diagramIndex);
		diagramPresentationModel.getConnectionProfiles().put(connectionAdapter, connectionProfile);
	}
}
