/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/16
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import java.util.Collection;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.datatype.DomainModel;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.model.index.IndexModel;

/**
 * {@link TableModel}に{@link IndexModel}を追加するEDITコマンド。
 * 
 * @see RemoveIndexCommand
 * @author daisuke
 */
public class AddIndexCommand extends AbstractAddToCollectionCommand<TableModel, IndexModel> {
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param tableModel 追加される{@link TableModel}
	 * @param indexModel 追加する{@link DomainModel}
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddIndexCommand(EventBroker eventBroker, TableModel tableModel, IndexModel indexModel) {
		super(eventBroker, tableModel, indexModel);
	}
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param tableModel 追加される{@link TableModel}
	 * @param index 追加位置をあらわすインデックス値
	 * @param indexModel 追加する{@link DomainModel}
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public AddIndexCommand(EventBroker eventBroker, TableModel tableModel, int index, IndexModel indexModel) {
		super(eventBroker, tableModel, indexModel, index);
	}
	
	public Command getNegateCommand() {
		return new RemoveIndexCommand(getEventBroker(), getTarget(), getElement());
	}
	
	@Override
	public Collection<? super IndexModel> getTargetCollection() {
		return getTarget().getIndexes();
	}
}
