/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/16
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import java.util.Collection;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.index.IndexColumnModel;
import org.jiemamy.model.index.IndexModel;

/**
 * {@link IndexModel}から{@link IndexColumnModel}を削除するEDITコマンド。
 * 
 * @see AddIndexCommand
 * @author daisuke
 */
public class RemoveIndexColumnCommand extends AbstractRemoveFromCollectionCommand<IndexModel, IndexColumnModel> {
	
	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param indexModel 削除元の{@link IndexModel}
	 * @param indexColumnModel 削除される{@link IndexColumnModel}
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public RemoveIndexColumnCommand(EventBroker eventBroker, IndexModel indexModel, IndexColumnModel indexColumnModel) {
		super(eventBroker, indexModel, indexColumnModel);
	}
	
	public Command getNegateCommand() {
		return new AddIndexColumnCommand(getEventBroker(), getTarget(), getElement());
	}
	
	@Override
	public Collection<? super IndexColumnModel> getTargetCollection() {
		return getTarget().getIndexColumns();
	}
}
