/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/03/17
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.editcommand;

import org.apache.commons.lang.Validate;

import org.jiemamy.EventBroker;
import org.jiemamy.editcommand.Command;
import org.jiemamy.model.JiemamyElement;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.ColumnRef;
import org.jiemamy.model.dataset.RecordModel;

/**
 * {@link RecordModel}の指定カラムのデータを設定するEDITコマンド。
 * 
 * @author daisuke
 */
public class SetRecordValueCommand extends AbstractCommand {
	
	/** 対象のレコード */
	private final RecordModel recordModel;
	
	/** 対象のカラム */
	private final ColumnModel columnModel;
	
	/** 対象のカラムの参照オブジェクト */
	private final ColumnRef columnRef;
	
	/** 新しい値 */
	private final String newValue;
	
	/** 以前の値 */
	private final String oldValue;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param eventBroker イベント通知用{@link EventBroker}
	 * @param recordModel 対象レコード
	 * @param columnModel 対象カラム
	 * @param newValue データ
	 * @throws IllegalArgumentException 引数newValue<b>以外</b>に{@code null}を与えた場合
	 */
	public SetRecordValueCommand(EventBroker eventBroker, RecordModel recordModel, ColumnModel columnModel,
			String newValue) {
		super(eventBroker);
		Validate.notNull(recordModel);
		Validate.notNull(columnModel);
		this.recordModel = recordModel;
		this.columnModel = columnModel;
		this.newValue = newValue;
		columnRef = recordModel.getJiemamy().getFactory().newReference(columnModel);
		oldValue = recordModel.getValues().get(columnRef);
	}
	
	public Command getNegateCommand() {
		return new SetRecordValueCommand(getEventBroker(), recordModel, columnModel, oldValue);
	}
	
	public JiemamyElement getTarget() {
		return recordModel;
	}
	
	@Override
	protected void execute0() {
		recordModel.getValues().put(columnRef, newValue);
	}
}
