/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/09/29
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model;

import java.util.Iterator;
import java.util.List;

import org.apache.commons.collections15.iterators.UnmodifiableIterator;
import org.apache.commons.lang.Validate;

import org.jiemamy.model.DiagramPresentationModel;
import org.jiemamy.model.DiagramPresentations;
import org.jiemamy.model.RootModel;
import org.jiemamy.utils.ValidateUtil;

/**
 * ダイアグラム表現の集合モデルクラス。
 * 
 * @author daisuke
 */
public class DiagramPresentationsImpl implements DiagramPresentations {
	
	/**
	 * 属するRootModel
	 * 
	 * 今のところ使用していないが、eventまわりで必要なんじゃないかと思っている。
	 */
	@SuppressWarnings("unused")
	private final RootModel rootModel;
	
	/** ダイアグラム表現のリスト */
	private List<DiagramPresentationModel> presentations;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param rootModel このダイアグラムで表示するRootModel
	 */
	public DiagramPresentationsImpl(RootModel rootModel) {
		this.rootModel = rootModel;
	}
	
	public void add(DiagramPresentationModel presentation) {
		assert presentations != null;
		Validate.notNull(presentation);
		presentations.add(presentation);
	}
	
	public DiagramPresentationModel get(int index) {
		assert presentations != null;
		return presentations.get(index);
	}
	
	public Iterator<DiagramPresentationModel> iterator() {
		assert presentations != null;
		return UnmodifiableIterator.decorate(presentations.iterator());
	}
	
	public void remove(DiagramPresentationModel presentation) {
		assert presentations != null;
		Validate.notNull(presentation);
		presentations.remove(presentation);
	}
	
	/**
	 * ダイアグラム表現のリストを設定する。
	 * 
	 * @param presentations ダイアグラム表現のリスト
	 */
	public void setPresentations(List<DiagramPresentationModel> presentations) {
		Validate.notNull(presentations);
		ValidateUtil.injectionSetter(this.presentations);
		this.presentations = presentations;
	}
	
	public int size() {
		assert presentations != null;
		return presentations.size();
	}
	
	@Override
	public String toString() {
		return presentations.toString();
	}
	
}
