/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/06/09
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.internal.model.node;

import java.util.Collection;
import java.util.List;

import org.apache.commons.lang.Validate;

import org.jiemamy.exception.IllegalImplementationException;
import org.jiemamy.model.attribute.constraint.ForeignKey;
import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.entity.EntityModel;
import org.jiemamy.model.entity.TableModel;
import org.jiemamy.model.node.NodeAdapter;
import org.jiemamy.utils.CollectionsUtil;

/**
 * ノード（Table, View等）のAbstractモデル。
 * 
 * @author daisuke
 */
public class NodeAdapterImpl implements NodeAdapter {
	
	private final EntityModel coreEntityModel;
	

	/**
	 * インスタンスを生成する。
	 * 
	 * @param coreEntityModel ノードの基礎となるエンティティ
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public NodeAdapterImpl(EntityModel coreEntityModel) {
		Validate.notNull(coreEntityModel);
		this.coreEntityModel = coreEntityModel;
	}
	
	public int compareTo(NodeAdapter o) {
		if (o == null) {
			return -1;
		}
		if (getClass() != o.getClass()) {
			return this.getClass().getName().compareTo(o.getClass().getName());
		}
		return coreEntityModel.getId().compareTo(((NodeAdapterImpl) o).coreEntityModel.getId());
	}
	
	public List<ConnectionAdapter> getSourceConnections() {
		if (coreEntityModel == null) {
			throw new IllegalImplementationException("Custom node must be overriden getSourceConnections method");
		}
		List<ConnectionAdapter> result = CollectionsUtil.newArrayList();
		if (coreEntityModel instanceof TableModel) {
			TableModel tableModel = (TableModel) coreEntityModel;
			List<ForeignKey> foreignKeys = tableModel.findAttributes(ForeignKey.class);
			for (ForeignKey foreignKey : foreignKeys) {
				result.add(foreignKey.getAdapter(ConnectionAdapter.class));
			}
		}
		return result;
	}
	
	public List<ConnectionAdapter> getTargetConnections() {
		if (coreEntityModel == null) {
			throw new IllegalImplementationException("Custom node must be overriden getSourceConnections method");
		}
		List<ConnectionAdapter> result = CollectionsUtil.newArrayList();
		if (coreEntityModel instanceof TableModel) {
			TableModel targetTable = (TableModel) coreEntityModel;
			Collection<EntityModel> sourceEntities = targetTable.findSubEntities(false);
			for (EntityModel sourceEntity : sourceEntities) {
				if (sourceEntity instanceof TableModel) {
					TableModel sourceTable = (TableModel) sourceEntity;
					List<ForeignKey> foreignKeys = sourceTable.findAttributes(ForeignKey.class);
					for (ForeignKey foreignKey : foreignKeys) {
						if (foreignKey.findReferencedEntity() == targetTable) {
							result.add(foreignKey.getAdapter(ConnectionAdapter.class));
						}
					}
				}
			}
		}
		return result;
	}
	
	@Override
	public String toString() {
		return "NodeAdapter(" + coreEntityModel.getName() + ")";
//		return ToStringBuilder.reflectionToString(this, ToStringStyle.SHORT_PREFIX_STYLE);
	}
	
	public EntityModel unwrap() {
		return coreEntityModel;
	}
}
