/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/09/17
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model;

import java.util.Map;

import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.node.NodeAdapter;

/**
 * ダイアグラム表現を表すモデルインターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface DiagramPresentationModel extends JiemamyElement {
	
	/**
	 * コネクションのビジュアル情報を取得する。
	 * 
	 * <p>モデルとしては存在するがダイアグラム上で非表示にするコネクションは、{@link Map#containsKey(Object)}が
	 * {@code true}となる。</p>
	 * 
	 * <p>このメソッドは、インスタンスの持つフィールドをそのまま返す。返される{@link Map}を直接操作することで、
	 * このオブジェクトのフィールドとして保持される{@link Map}を変更することができる。</p>
	 * 
	 * @return コネクションのビジュアル情報
	 * @since 0.2
	 */
	Map<ConnectionAdapter, ConnectionProfile> getConnectionProfiles();
	
	/**
	 * ノードのビジュアル情報を取得する。
	 * 
	 * <p>モデルとしては存在するがダイアグラム上で非表示にするノードは、{@link Map#containsKey(Object)}が
	 * {@code true}となる。</p>
	 * 
	 * <p>このメソッドは、インスタンスの持つフィールドをそのまま返す。返される{@link Map}を直接操作することで、
	 * このオブジェクトのフィールドとして保持される{@link Map}を変更することができる。</p>
	 * 
	 * @return ノードのビジュアル情報
	 * @since 0.2
	 */
	Map<NodeAdapter, NodeProfile> getNodeProfiles();
	
	/**
	 * 表示レベルを取得する。
	 * 
	 * @return 表示レベル. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	Level getLevel();
	
	/**
	 * 物理/論理モードを取得する。
	 * 
	 * @return 物理/論理モード. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	Mode getMode();
	
	/**
	 * プレゼンテーション名を取得する。
	 * 
	 * @return プレゼンテーション名. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	String getName();
	
	/**
	 * 表示レベルを取得する。
	 * 
	 * @param level 表示レベル
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	void setLevel(Level level);
	
	/**
	 * 物理/論理モードを取得する。
	 * 
	 * @param mode 物理/論理モード
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	void setMode(Mode mode);
	
	/**
	 * プレゼンテーション名を設定する。
	 * 
	 * <p>未設定とする場合は{@code null}を与える。</p>
	 * 
	 * @param name プレゼンテーション名
	 * @since 0.2
	 */
	void setName(String name);
	
}
