/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/02/04
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model;

import org.jiemamy.model.geometory.JmColor;
import org.jiemamy.model.geometory.JmRectangle;

/**
 * ノードのビジュアル情報インターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface NodeProfile extends JiemamyElement {
	
	/**
	 * ノードのレイアウト情報を取得する。
	 * 
	 * @return ノードのレイアウト情報. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	JmRectangle getBoundary();
	
	/**
	 * ノードの色情報を取得する。
	 * 
	 * @return ノードの色情報. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	JmColor getColor();
	
	/**
	 * ノードのレイアウト情報を設定する。
	 * 
	 * <p>未設定とする場合は{@code null}を与える。</p>
	 * 
	 * @param boundary ノードのレイアウト情報
	 * @since 0.2
	 */
	void setBoundary(JmRectangle boundary);
	
	/**
	 * ノードの色情報を設定する。
	 * 
	 * <p>未設定とする場合は{@code null}を与える。</p>
	 * 
	 * @param color ノードの色情報
	 * @since 0.2
	 */
	void setColor(JmColor color);
	
}
