/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/12/30
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model.datatype;

import org.jiemamy.utils.Adaptable;

/**
 * DBに本来組み込まれているデータ型を表すインターフェイス。つまり、Domain型ではないプリミティブなデータ型の記述子。
 * 
 * @since 0.2
 * @author daisuke
 */
public interface BuiltinDataType extends DataType, Adaptable {
	
	/**
	 *  型カテゴリを取得する。
	 *  
	 * @return 型カテゴリ. 未設定の場合は{@code null}
	 * @since 0.2
	 */
	DataTypeCategory getCategory();
	
	/**
	 * データ型名を取得する。
	 * 
	 * @return データ型名. 未設定の場合は型カテゴリ名を返す
	 * @since 0.2
	 */
	String getTypeName();
	
	/**
	 * 型カテゴリを設定する。
	 * 
	 * <p>未設定とする場合は{@code null}を与えるが、モデルとしては無効となる。</p>
	 * 
	 * @param category 型カテゴリ
	 * @since 0.2
	 */
	void setCategory(DataTypeCategory category);
	
	/**
	 * データ型名を設定する。
	 * 
	 * <p>未設定とする場合は{@code null}を与える。</p>
	 * 
	 * @param typeName データ型名
	 * @since 0.2
	 */
	void setTypeName(String typeName);
	
}
