/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/07/20
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model.datatype.adapter;

import org.jiemamy.model.Adapter;
import org.jiemamy.model.AdapterType;
import org.jiemamy.model.datatype.DataTypeAdapter;

/**
 * 精度とスケールを持つDataType用のアダプタ。
 * 
 * @author daisuke
 */
@Adapter(AdapterType.MODEL)
public class PrecisionedDataTypeAdapter implements DataTypeAdapter {
	
	/** 精度 */
	private Integer precision;
	
	/** スケール */
	private Integer scale;
	

	public void copy(DataTypeAdapter src) {
		if (src == null) {
			throw new IllegalArgumentException("The validated object is null");
		}
		if (src instanceof PrecisionedDataTypeAdapter) {
			precision = ((PrecisionedDataTypeAdapter) src).precision;
			scale = ((PrecisionedDataTypeAdapter) src).scale;
		} else {
			throw new IllegalArgumentException(src.getClass().toString() + " (expected is " + this.getClass().getName()
					+ ")");
		}
	}
	
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final PrecisionedDataTypeAdapter other = (PrecisionedDataTypeAdapter) obj;
		if (precision == null) {
			if (other.precision != null) {
				return false;
			}
		} else if (precision.equals(other.precision) == false) {
			return false;
		}
		if (scale == null) {
			if (other.scale != null) {
				return false;
			}
		} else if (scale.equals(other.scale) == false) {
			return false;
		}
		return true;
	}
	
	/**
	 * 精度を取得する。
	 * 
	 * @return 精度
	 */
	public Integer getPrecision() {
		return precision;
	}
	
	/**
	 * スケールを取得する。
	 * 
	 * @return スケール
	 */
	public Integer getScale() {
		return scale;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((precision == null) ? 0 : precision.hashCode());
		result = prime * result + ((scale == null) ? 0 : scale.hashCode());
		return result;
	}
	
	/**
	 * 精度を設定する。
	 * 
	 * @param precision 精度
	 */
	public void setPrecision(Integer precision) {
		this.precision = precision;
	}
	
	/**
	 * スケールを設定する。
	 * 
	 * @param scale スケール
	 */
	public void setScale(Integer scale) {
		this.scale = scale;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		if (precision != null) {
			sb.append("(");
			sb.append(precision);
			if (scale != null) {
				sb.append(", ");
				sb.append(scale);
			}
			sb.append(")");
		}
		return sb.toString();
	}
}
