/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/07/20
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model.datatype.adapter;

import org.jiemamy.model.Adapter;
import org.jiemamy.model.AdapterType;
import org.jiemamy.model.datatype.DataTypeAdapter;

/**
 * タイムゾーン管理の有無を持つDataType用のアダプタ。
 * 
 * @author daisuke
 */
@Adapter(AdapterType.MODEL)
public class TimezonedDataTypeAdapter implements DataTypeAdapter {
	
	/** タイムゾーンを管理するかどうか */
	private Boolean withTimezone;
	

	public void copy(DataTypeAdapter src) {
		if (src == null) {
			throw new IllegalArgumentException("The validated object is null");
		}
		if (src instanceof TimezonedDataTypeAdapter) {
			withTimezone = ((TimezonedDataTypeAdapter) src).withTimezone;
		} else {
			throw new IllegalArgumentException(src.getClass().toString() + " (expected is " + this.getClass().getName()
					+ ")");
		}
	}
	
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		final TimezonedDataTypeAdapter other = (TimezonedDataTypeAdapter) obj;
		if (withTimezone == null) {
			if (other.withTimezone != null) {
				return false;
			}
		} else if (withTimezone.equals(other.withTimezone) == false) {
			return false;
		}
		return true;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((withTimezone == null) ? 0 : withTimezone.hashCode());
		return result;
	}
	
	/**
	 * タイムゾーンを管理するかどうかを取得する。
	 * 
	 * @return 精度
	 */
	public Boolean isWithTimezone() {
		return withTimezone;
	}
	
	/**
	 * タイムゾーンを管理するかどうかを設定する。
	 * 
	 * @param withTimezone 精度
	 */
	public void setWithTimezone(Boolean withTimezone) {
		this.withTimezone = withTimezone;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		if (withTimezone != null) {
			sb.append(" ");
			sb.append(withTimezone ? "WITH" : "WITHOUT");
			sb.append(" TIMEZONE");
		}
		return sb.toString();
	}
}
