/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/09/17
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.model.node;

import java.util.Collection;

import org.jiemamy.model.Adapter;
import org.jiemamy.model.AdapterType;
import org.jiemamy.model.connection.ConnectionAdapter;
import org.jiemamy.model.entity.EntityModel;

/**
 * ダイアグラムにおける「節点」を表すアダプタインターフェイス。
 * 
 * @since 0.2
 * @author daisuke
 */
@Adapter(AdapterType.LOGIC)
public interface NodeAdapter extends Comparable<NodeAdapter> {
	
	/**
	 * このモデルを接続元とするコネクションの集合を取得する。
	 * 
	 * <p>返される{@link Collection}は他に影響を及ぼさない独立したインスタンスである。</p>
	 * 
	 * @return コネクションの集合
	 * @since 0.2
	 */
	Collection<ConnectionAdapter> getSourceConnections();
	
	/**
	 * このモデルを接続先とするコネクションの集合を取得する。
	 * 
	 * <p>返される{@link Collection}は他に影響を及ぼさない独立したインスタンスである。</p>
	 * 
	 * @return コネクションの集合
	 * @since 0.2
	 */
	Collection<ConnectionAdapter> getTargetConnections();
	
	/**
	 * このオブジェクトでラッピングされた、コアオブジェクトを取得する。
	 * 
	 * @return コアとなっているエンティティ
	 */
	EntityModel unwrap();
}
