/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/06/09
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.serializer;

import java.io.InputStream;
import java.io.OutputStream;

import org.jiemamy.model.RootModel;

/**
 * シリアライザインターフェイス。
 * 
 * <p>シリアライザの実装クラスはステートレスでなければならない。</p>
 * 
 * @author daisuke
 */
public interface JiemamySerializer {
	
	/**
	 * {@link InputStream} から {@link RootModel} にデシリアライズする。
	 * 
	 * <p>{@code null}を返してはならない。</p>
	 * 
	 * @param in デシリアライズするInputStream
	 * @return デシリアライズしたRootModel
	 * @throws SerializationException デシリアライズに失敗した時
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	RootModel deserialize(InputStream in) throws SerializationException;
	
	/**
	 * {@link RootModel} を {@link InputStream} にシリアライズする。
	 * 
	 * @param rootModel シリアライズする {@link RootModel}
	 * @param out シリアライズ結果を出力するstream
	 * @throws SerializationException シリアライズに失敗した時
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 * @since 0.2
	 */
	void serialize(RootModel rootModel, OutputStream out) throws SerializationException;
	
}
