/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/19
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils.model;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.exception.UnexpectedConditionError;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.ColumnRef;
import org.jiemamy.model.attribute.constraint.ForeignKey;

/**
 * {@link ForeignKey}のユーティリティクラス。
 * 
 * @author daisuke
 */
public final class ForeignKeyUtil {
	
	/**
	 * マッピング情報を追加する。
	 * 
	 * @param foreignKey 対象外部キー制約モデル
	 * @param keyColumn キーカラム
	 * @param referenceColumn 参照カラム
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static void addMapping(ForeignKey foreignKey, ColumnModel keyColumn, ColumnModel referenceColumn) {
		JiemamyFactory factory = foreignKey.getJiemamy().getFactory();
		addMapping(foreignKey, factory.newReference(keyColumn), factory.newReference(referenceColumn));
	}
	
	/**
	 * マッピング情報を追加する。
	 * 
	 * @param foreignKey 対象外部キー制約モデル
	 * @param keyColumn キーカラムの参照
	 * @param referenceColumn 参照カラムの参照
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static void addMapping(ForeignKey foreignKey, ColumnRef keyColumn, ColumnRef referenceColumn) {
		Validate.notNull(foreignKey);
		Validate.notNull(keyColumn);
		Validate.notNull(referenceColumn);
		
		foreignKey.getKeyColumns().add(keyColumn);
		foreignKey.getReferenceColumns().add(referenceColumn);
	}
	
	/**
	 * {@link ColumnModel}を {@link ColumnRef}に変換し、参照カラムに追加する。
	 * 
	 * @param foreignKey 対象外部キー制約モデル
	 * @param columnModel 追加する参照カラム
	 * @throws IllegalArgumentException 引数に{@code null}を与えた場合
	 */
	public static void addReferenceColumn(ForeignKey foreignKey, ColumnModel columnModel) {
		Validate.notNull(foreignKey);
		Validate.notNull(columnModel);
		
		ColumnRef ref = columnModel.getJiemamy().getFactory().newReference(columnModel);
		foreignKey.getReferenceColumns().add(ref);
	}
	
	private ForeignKeyUtil() {
		throw new UnexpectedConditionError("不到達ポイント");
	}
}
