/*

 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2009/01/22
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.utils.model;

import org.apache.commons.lang.Validate;

import org.jiemamy.JiemamyFactory;
import org.jiemamy.exception.UnexpectedConditionError;
import org.jiemamy.model.attribute.ColumnModel;
import org.jiemamy.model.attribute.ColumnRef;
import org.jiemamy.model.dataset.RecordModel;

/**
 * {@link RecordModel}のユーティリティクラス。
 * 
 * @author daisuke
 */
public final class RecordUtil {
	
	/**
	 * {@link RecordModel}にデータを設定・追加する。
	 * 
	 * @param recordModel 対象レコード
	 * @param columnModel 対象カラム
	 * @param value データ may be null
	 * @throws IllegalArgumentException 引数recordModel, columnModelに{@code null}を与えた場合
	 */
	public static void addValue(RecordModel recordModel, ColumnModel columnModel, String value) {
		Validate.notNull(recordModel);
		Validate.notNull(columnModel);
		
		JiemamyFactory factory = columnModel.getJiemamy().getFactory();
		ColumnRef ref = factory.newReference(columnModel);
		recordModel.getValues().put(ref, value);
	}
	
	private RecordUtil() {
		throw new UnexpectedConditionError("不到達ポイント");
	}
}
