/*
 * Copyright 2007-2009 Jiemamy Project and the Others.
 * Created on 2008/11/05
 *
 * This file is part of Jiemamy.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.jiemamy.xml;

import java.net.URI;
import java.net.URISyntaxException;

import org.jiemamy.exception.UnexpectedConditionError;

/**
 * XML名前空間定数クラス。
 * 
 * @since 0.2
 * @author daisuke
 */
public enum ViewNamespace implements JiemamyNamespace {
	
	/** Jiemamy view specifications */
	NS_VIEW("view", "http://jiemamy.org/xml/ns/view"),

	/**  */
	NONE("", "");
	
	/** 名前空間prefix */
	private final String prefix;
	
	/** 名前空間URI */
	private final URI namespaceURI;
	
	private final String xmlSchemaLocation;
	

	ViewNamespace(String prefix, String namespaceURI) {
		this(prefix, namespaceURI, null);
	}
	
	ViewNamespace(String prefix, String namespaceURI, String xmlSchemaLocation) {
		this.prefix = prefix;
		try {
			this.namespaceURI = new URI(namespaceURI);
			this.xmlSchemaLocation = xmlSchemaLocation;
		} catch (URISyntaxException e) {
			throw new UnexpectedConditionError("URI記述ミス？", e);
		}
	}
	
	public URI getNamespaceURI() {
		return namespaceURI;
	}
	
	public String getPrefix() {
		return prefix;
	}
	
	public String getXmlSchemaLocation() {
		return xmlSchemaLocation;
	}
}
